@@ -7,7 +7,31 @@ use Text::Balanced qw( extract_multiple extract_bracketed );
 
 use Bigtop::ScriptHelp qw( valid_ident );
 
-my $default_columns = 'ident,description';
+sub get_default_base_columns {
+    return {
+        is_normal_default => {
+            id       => {
+                where => 'front',
+                types => [ 'int4', 'primary_key', 'auto' ]
+            },
+            created  => {
+                where => 'rear',
+                types => [ 'datetime' ],
+            },
+            modified => {
+                where => 'rear',
+                types => [ 'datetime' ],
+            },
+        },
+        normal_defaults => [
+            qw( id created modified )
+        ],
+    };
+}
+
+sub get_default_filler_columns {
+    return 'ident,description';
+}
 
 sub get_db_layout {
     my $self   = shift;
@@ -31,6 +55,7 @@ sub get_db_layout {
     my @joiners;
     my %foreign_key_for;
     my %columns;
+    my $default_columns = $self->get_default_filler_columns();
 
     $art =~ s/^\s+//;
     $art =~ s/\s+$//;
@@ -44,8 +69,8 @@ sub get_db_layout {
             # now pull column descriptions, if present
             my ( $cols1, $cols2 );
 
-            ( $table1, $cols1 ) = _get_columns( $table1 );
-            ( $table2, $cols2 ) = _get_columns( $table2 );
+            ( $table1, $cols1 ) = $self->get_columns( $table1 );
+            ( $table2, $cols2 ) = $self->get_columns( $table2 );
 
             unless ( defined $table1 and valid_ident( $table1 )
                         and
@@ -95,12 +120,13 @@ sub get_db_layout {
             unless ( defined $tables->{ $art_element } ) {
                 push @new_tables, $art_element;
                 $tables->{ $art_element }++;
-                $columns{ $art_element } = _parse_columns( $default_columns )
-                    unless $columns{ $art_element };
+                $columns{ $art_element } =
+                    $self->parse_columns( $default_columns )
+                        unless $columns{ $art_element };
             }
         }
         else {
-            my ( $table, $cols ) = _get_columns( $art_element );
+            my ( $table, $cols ) = $self->get_columns( $art_element );
 
             unless ( valid_ident( $table ) ) {
                 die "Invalid ASCII art (3): $art_element\n";
@@ -114,7 +140,7 @@ sub get_db_layout {
         }
     }
 
-    my $parsed_defaults = _parse_columns( $default_columns );
+    my $parsed_defaults = $self->parse_columns( $default_columns );
     NEW_TABLE:
     foreach my $new_table ( @new_tables ) { # add default cols as needed
         next NEW_TABLE if defined $columns{ $new_table };
@@ -130,7 +156,8 @@ sub get_db_layout {
     }
 }
 
-sub _get_columns {
+sub get_columns {
+    my $self  = shift;
     my $table = shift;
 
     my ( $name, $raw ) = extract_multiple(
@@ -144,24 +171,22 @@ sub _get_columns {
         $raw =~ s/^\(//;
         $raw =~ s/\)$//;
 
-        return ( $name, _parse_columns( $raw ) );
+        return ( $name, $self->parse_columns( $raw ) );
     }
     else {
         return ( $name );
     }
 }
 
-sub _parse_columns {
-    my $raw = shift;
+sub parse_columns {
+    my $self = shift;
+    my $raw  = shift;
 
     my @pieces = split /,/, $raw;
 
     my $you_dont_want_em  = 0;
-    my %is_normal_default = (
-        id       => 1,
-        created  => 1,
-        modified => 1,
-    );
+    my $defaults = $self->get_default_base_columns;
+    my $is_normal_default = $defaults->{ is_normal_default };
     my %you_dont_want;
 
     my @columns;
@@ -184,24 +209,123 @@ sub _parse_columns {
 
         push @columns, \%col_hash;
 
-        $you_dont_want{ $name }++ if defined $is_normal_default{ $name };
+        $you_dont_want{ $name }++ if defined $is_normal_default->{ $name };
     }
 
-    unshift @columns, {
-                name  => 'id',
-                types => [ 'int4', 'primary_key', 'auto' ]
+    COL:
+    foreach my $col ( @{ $defaults->{ normal_defaults } } ) {
+        unless ( $you_dont_want{ $col } ) {
+            if ( not defined $is_normal_default->{ $col }{ where } ) {
+                warn "normal_defaults column '$col' has no where "
+                    . "in is_normal_default\n";
+                next COL;
             }
-            unless $you_dont_want{ id };
-
-    push @columns, { name => 'created',  types => [ 'datetime' ] }
-            unless $you_dont_want{ created };
-
-    push @columns, { name => 'modified', types => [ 'datetime' ] }
-            unless $you_dont_want{ modified };
+            if ( not defined $is_normal_default->{ $col }{ types } ) {
+                warn "normal_defaults column '$col' has no types "
+                    . "in is_normal_default\n";
+                next COL;
+            }
+            if ( $is_normal_default->{ $col }{ where } eq 'front' ) {
+                unshift @columns, {
+                    name  => $col,
+                    types => $is_normal_default->{ $col }{ types },
+                }
+            }
+            else {
+                push @columns, {
+                    name  => $col,
+                    types => $is_normal_default->{ $col }{ types },
+                }
+            }
+        }
+    }
 
     return \@columns;
 }
 
+sub print_instructions {
+    my $class        = shift;
+    my $app_name     = shift;
+    my $build_dir    = shift;
+    my $built_sqlite = shift;
+
+    my $heading   = << "EO_SQLite_Basic";
+
+I have generated your '$app_name' application.  To run the application:
+
+    cd $build_dir
+    sqlite app.db < docs/schema.sqlite
+    ./app.server [ port ]
+EO_SQLite_Basic
+
+    if ( $built_sqlite ) {
+        $heading = << "EO_SQLite_Prebuilt";
+
+I have generated your '$app_name' application.  I have also taken the liberty
+of making an sqlite database for it to use.  To run the application:
+
+    cd $build_dir
+    ./app.server [ port ]
+EO_SQLite_Prebuilt
+    }
+
+    print << "EO_Instructions";
+$heading
+The app.server runs on port 8080 by default.
+
+Once the app.server starts, it will print a list of the urls it can serve.
+Point your browser to one of those and enjoy.
+
+If you prefer to run the app with Postgres or MySQL type one of these:
+
+    bigtop --pg_help
+    bigtop --mysql_help
+
+EO_Instructions
+
+}
+
+sub help_pg {
+    print << "EO_pg_help";
+
+For PostgreSQL, in your build directory:
+
+    createdb app.db -U postgres
+    psql app.db -U regular_user < docs/schema.postgres
+    ./app.server --dbd=Pg --dbuser=regular_user --dppass='secret'
+
+Supply passwords as prompted when creating and building the database.
+You may abbreviate --dbd as -d, --dbuser as -u, and --dbpass as -p.
+
+If you change the name from app.db, supply --dbname (aka -n) to app.server.
+
+EO_pg_help
+
+    exit 0;
+}
+
+sub help_mysql {
+    my $class     = shift;
+    my $build_dir = shift;
+
+    print << "EO_mysql_help";
+
+For MySQL, in your build directory:
+
+    msyqladmin create app_db -u root -p
+    mysql -u root -p app_db < docs/schema.mysql
+    ./app.server --dbd=mysql --dbuser=regular_user \
+                 --dppass='secret' --dbname=app_db
+
+Supply passwords as prompted when creating and building the database.
+You may abbreviate --dbd as -d, --dbuser as -u, --dbpass as -p,
+and --dbname as -n.
+
+EO_mysql_help
+
+    exit 0;
+}
+
 1;
 
 =head1 NAME
@@ -218,7 +342,7 @@ tentmaker scripts:
 See L<KICKSTART SYNTAX> below for details, but note that kickstart could
 be a file whose contents are in kickstart syntax.
 
-If you are writing a script that want to leverage styles do this:
+If you are writing a script that wants to leverage styles do this:
 
     use Bigtop::ScriptHelp::Style;
 
@@ -231,15 +355,112 @@ If you are writing a script that want to leverage styles do this:
 See C<Bigtop::ScriptHelp::Style> for a description of what this module
 must do in general.
 
+=head1 SUBCLASSING
+
+As of version 0.33, this module has been revised to make subclassing
+easier.  This allows you complete control over what columns are generated
+by default.  All you need to do is subclass this module and implement
+two methods: C<get_default_base_columns> and C<get_default_filler_columns>.
+But, you can rely on this module to handle the original kickstart syntax.
+
 =head1 METHODS
 
 =over 4
 
+=item get_columns
+
+This method is for internal use, but is exposed so subclasses don't have
+to implement it.  It specifies that definitions like
+
+    tablename(col,col2:int)
+
+will be parsed with C<parse_columns> (see below).
+
 =item get_db_layout
 
 This method does not use standard in.  Instead, it expects
 kickstart syntax.  See L<KICKSTART SYNTAX> below.
 
+=item get_default_base_columns
+
+Subclasses override this method to control which columns are created by
+default.  Note that if a user explicitly declares a column in the
+parentheses of a table definition, the corresponding column in this
+collection is ignored.
+
+Returns a hash with two keys: C<is_normal_default> and C<normal_defaults>.
+C<is_normal_defaults> is a hash keyed by the name of each column with two
+keys: C<where> (either front or rear) and C<typees> (an anonymous array
+of Bigtop C<is> values, usually these are SQL types or other column
+definition phrases).  C<normal_defaults> is an anonymous array of column
+names, they must correspond to keys in C<is_normal_defaults>.  The order
+of the columns in the array controls when they are added to the list of
+columns.  But, remember that C<where> decides whether to unshift or push them
+into the list.
+
+For example, the method in this module does this:
+
+    return {
+        is_normal_default => {
+            id       => {
+                where => 'front',
+                types => [ 'int4', 'primary_key', 'auto' ]
+            },
+            created  => {
+                where => 'rear',
+                types => [ 'datetime' ],
+            },
+            modified => {
+                where => 'rear',
+                types => [ 'datetime' ],
+            },
+        },
+        normal_defaults => [
+            qw( id created modified )
+        ],
+    };
+
+
+=item get_default_filler_columns
+
+Suppose a table is in the kickstart file, but has no column definitions.
+It will get columns.  First, this method returns a string which is
+the default art for the table.  Second, as with all tables, columns
+returned by C<get_default_base_columns> are added.
+
+The method in this module returns:
+
+    return 'ident,description';
+
+If you return the empty string, no filler columns will be added to
+your tables.
+
+=item parse_columns
+
+This method is exposed so subclasses don't have to implement it.  It
+receives a kickstart art string and parses it into an anonymous array
+of columns.  Each element in the array is a hash with keys C<name> (the
+name of the SQL column) and C<types> (an anonymous hash of Bigtop
+C<is> values, which are an SQL type and a list of other column definition
+phrases).  There are other keys: C<default> and C<optional>.  These
+are used when the art includes C<=> or C<+>.
+
+=item print_instructions
+
+Called by bigtop script when it makes a new application containing
+table definitions (you used art with this style).  Prints instructions
+on how to start the development application using sqlite.
+
+=item help_pg
+
+Revises the instructions from C<print_instructions> so they are good
+for PostgreSQL.
+
+=item help_mysql
+
+Revises the instructions from C<print_instructions> so they are good
+for mysql.
+
 =back
 
 =head1 KICKSTART SYNTAX
@@ -348,7 +569,7 @@ for defaults and leading plus signs for optional fields.  For example:
     bigtop -n App 'family(name,+phone)<-child(name,birth_day:date)'
 
 By default all columns will have type varchar (but note that SQL backends
-translate that into some other string type for all supported databases,
+translate that into a valid string type for each supported database,
 if a bare varchar wouldn't work).  If you need some other type, use a colon,
 as I did for birth_day.  If your type definition needs multiple words, use
 colons instead of spaces.
@@ -384,7 +605,7 @@ You may mention a table as many times as you like, but only define its
 columns once.
 
 Finally, as mentioned in the L<SYNOPSIS>, and described in more detail below
-(see L<KICKSTART FILES>, you may put the kickstart in
+(see L<KICKSTART FILES>), you may put the kickstart in
 a file and supply the file name on the command line:
 
     tentmaker -n App app.kickstart
@@ -397,7 +618,10 @@ allow you to include spaces within a table's definition.
 
 Here is the formal syntax for each table definition:
 
-    name(COL_DEF[,COL_DEF...])
+    name[(COL_DEF[,COL_DEF...])]
+
+I'm following the convention that brackets enclose optional elements.
+Everything else appears as is, or is defined below.
 
 Where name is a valid SQL table name and COL_DEF is as follows:
 
@@ -424,7 +648,7 @@ can put it in a file and invoke bigtop or tentmaker like this:
 
     bigtop -n NewApp file.kickstart
 
-Unfortunately, you cannot currently pipe to bigtop to tentmaker, they
+Unfortunately, you cannot currently pipe to bigtop or tentmaker, they
 do not read from standard in.
 
 Here is an example kickstart file for a blogging application:
